@@ -28,7 +28,7 @@ Implementation Notes
 
 """
 
-import adafruit_bus_device.i2c_device as i2c_device
+from adafruit_bus_device import i2c_device
 from micropython import const
 from adafruit_cap1188.cap1188 import CAP1188
 
